OC.L10N.register(
    "news",
    {
    "Saved" : "Պահված",
    "Download" : "Բեռնել",
    "Close" : "Փակել",
    "Language" : "Լեզու",
    "Description" : "Նկարագրություն",
    "Refresh" : "Թարմացնել",
    "Folder" : "Պանակ",
    "New folder" : "Նոր պանակ",
    "Folder name" : "Պանակի անուն",
    "Credentials" : "Credentials",
    "Username" : "Օգտանուն",
    "Password" : "Գաղտնաբառ",
    "Create" : "Ստեղծել",
    "Rename" : "Վերանվանել",
    "Delete" : "հեռացնել",
    "Settings" : "Կարգավորումներ",
    "Import" : "Ներմուծում",
    "Export" : "Արտահանում",
    "Help" : "Օգնություն"
},
"nplurals=2; plural=(n != 1);");
